@@ -451,10 +451,10 @@ netstatus_iface_get_sockfd (NetstatusIface *iface)
 
 static gboolean
 netstatus_iface_poll_iface_statistics (NetstatusIface *iface,
-				       long           *in_packets,
-				       long           *out_packets,
-				       long           *in_bytes,
-				       long           *out_bytes)
+				       gulong         *in_packets,
+				       gulong         *out_packets,
+				       gulong         *in_bytes,
+				       gulong         *out_bytes)
 {
   char *error_message;
 
@@ -485,8 +485,8 @@ netstatus_iface_poll_state (NetstatusIface *iface)
   struct ifreq   if_req;
   gboolean       tx, rx;
   int            fd;
-  long           in_packets, out_packets;
-  long           in_bytes, out_bytes;
+  gulong         in_packets, out_packets;
+  gulong         in_bytes, out_bytes;
 
   if (!(fd = netstatus_iface_get_sockfd (iface)))
     return NETSTATUS_STATE_DISCONNECTED;
